==> haskell-curve25519-0.2.8-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-curve25519.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 curve25519
version:              0.2.8
visibility:           public
id:                   curve25519-0.2.8-H6GmyIljySzKBIP6CvfYU8
key:                  curve25519-0.2.8-H6GmyIljySzKBIP6CvfYU8
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/curve25519
synopsis:
    Fast implementations of the curve25519 elliptic curve primitives.

description:
    Haskell bindings and extensions to the curve25519-donna
    codebase. This module is a pretty straightforward implementation
    of the basic cryptographic routines you'\''d want from a project that
    uses curve25519: key generation, and key agreement. For further
    functionality, you'\''ll want to look elsewhere.

category:             Math
abi:                  e21aab0431c432af210efd674bd6ada5
exposed:              True
exposed-modules:
    Crypto.Curve25519 Crypto.Curve25519.Exceptions
    Crypto.Curve25519.Pure

import-dirs:          /usr/lib/ghc-9.2.8/site-local/curve25519-0.2.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/curve25519-0.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-curve25519
hs-libraries:         HScurve25519-0.2.8-H6GmyIljySzKBIP6CvfYU8
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    crypto-api-0.13.3-AGHt7g1Fqp46wmMl31ZVp4

haddock-interfaces:   /usr/share/doc/haskell-curve25519/html/curve25519.haddock
haddock-html:         /usr/share/doc/haskell-curve25519/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-curve25519-0.2.8-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-curve25519.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 curve25519
version:              0.2.8
visibility:           public
id:                   curve25519-0.2.8-7NMmC7eDuaI3ekvM9RcWiK
key:                  curve25519-0.2.8-7NMmC7eDuaI3ekvM9RcWiK
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/curve25519
synopsis:
    Fast implementations of the curve25519 elliptic curve primitives.

description:
    Haskell bindings and extensions to the curve25519-donna
    codebase. This module is a pretty straightforward implementation
    of the basic cryptographic routines you'\''d want from a project that
    uses curve25519: key generation, and key agreement. For further
    functionality, you'\''ll want to look elsewhere.

category:             Math
abi:                  39f1c31af0cf39601ec08b0e2cf36927
exposed:              True
exposed-modules:
    Crypto.Curve25519 Crypto.Curve25519.Exceptions
    Crypto.Curve25519.Pure

import-dirs:          /usr/lib/ghc-9.2.8/site-local/curve25519-0.2.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/curve25519-0.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-curve25519
hs-libraries:         HScurve25519-0.2.8-7NMmC7eDuaI3ekvM9RcWiK
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    crypto-api-0.13.3-EytQX0lxAJPL6DQgNvFnGv

haddock-interfaces:   /usr/share/doc/haskell-curve25519/html/curve25519.haddock
haddock-html:         /usr/share/doc/haskell-curve25519/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
